==> dscript-0.1.0.tgz: package/lib/index.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var _htmlTags = require('html-tags');

var _htmlTags2 = _interopRequireDefault(_htmlTags);

var _objectAssign = require('object-assign');

var _objectAssign2 = _interopRequireDefault(_objectAssign);

var _parseCssClassIdSelector = require('parse-css-class-id-selector');

var _parseCssClassIdSelector2 = _interopRequireDefault(_parseCssClassIdSelector);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getClassesAndId = function getClassesAndId(selector) {
  var _parseCssClassIdSelec = (0, _parseCssClassIdSelector2.default)(selector);

  var classNames = _parseCssClassIdSelec.classNames;
  var id = _parseCssClassIdSelec.id;


  var classesAndId = {};

  if (classNames.length) {
    classesAndId.class = classNames.join(' ');
  }

  if (id) {
    classesAndId.id = id;
  }

  return classesAndId;
};

module.exports = function (createElement) {
  if (typeof createElement !== 'function') {
    throw new TypeError('Expected createElement to be a function');
  }

  var creator = function creator(tagOrComponent) {
    return function (classesAndId, attrs, children) {
      var attrsToPass = attrs || {},
          childrenToPass = children || [];

      if (Array.isArray(classesAndId)) {
        childrenToPass = classesAndId;
      } else if ((typeof classesAndId === 'undefined' ? 'undefined' : _typeof(classesAndId)) === 'object') {
        attrsToPass = classesAndId;
        childrenToPass = attrs;
      }

      if (Array.isArray(attrsToPass)) {
        childrenToPass = attrs;
        attrsToPass = {};
      }

      if (typeof classesAndId === 'string') {
        (0, _objectAssign2.default)(attrsToPass, getClassesAndId(classesAndId));
      }

      return createElement(tagOrComponent, attrsToPass, childrenToPass);
    };
  };

  return _htmlTags2.default.reduce(function (acc, tag) {
    acc[tag] = creator(tag);
    return acc;
  }, creator);
};

==> dscript-0.1.1.tgz: package/lib/index.js <==
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var _htmlTags = require('html-tags');

var _htmlTags2 = _interopRequireDefault(_htmlTags);

var _objectAssign = require('object-assign');

var _objectAssign2 = _interopRequireDefault(_objectAssign);

var _parseCssClassIdSelector = require('parse-css-class-id-selector');

var _parseCssClassIdSelector2 = _interopRequireDefault(_parseCssClassIdSelector);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getClassesAndId = function getClassesAndId(selector) {
  var _parseCssClassIdSelec = (0, _parseCssClassIdSelector2.default)(selector);

  var classNames = _parseCssClassIdSelec.classNames;
  var id = _parseCssClassIdSelec.id;


  var classesAndId = {};

  if (classNames.length) {
    classesAndId.class = classNames.join(' ');
  }

  if (id) {
    classesAndId.id = id;
  }

  return classesAndId;
};

module.exports = function (createElement) {
  /* eslint complexity: [2, 9] */
  if (typeof createElement !== 'function') {
    throw new TypeError('Expected createElement to be a function');
  }

  var creator = function creator(tagOrComponent) {
    return function (classesAndId, attrs, children) {
      var attrsToPass = attrs || {},
          childrenToPass = children || [];

      if (Array.isArray(classesAndId)) {
        childrenToPass = classesAndId;
      } else if ((typeof classesAndId === 'undefined' ? 'undefined' : _typeof(classesAndId)) === 'object') {
        if (Array.isArray(attrsToPass)) {
          childrenToPass = attrsToPass;
        }
        attrsToPass = classesAndId;
      }

      if (Array.isArray(attrsToPass)) {
        childrenToPass = attrsToPass;
        attrsToPass = {};
      }

      if (typeof classesAndId === 'string') {
        (0, _objectAssign2.default)(attrsToPass, getClassesAndId(classesAndId));
      }

      return createElement(tagOrComponent, attrsToPass, childrenToPass);
    };
  };

  return _htmlTags2.default.reduce(function (acc, tag) {
    acc[tag] = creator(tag);
    return acc;
  }, creator);
};
